﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

using Windows.ApplicationModel.Core;
using Windows.UI.ViewManagement;

namespace MultiViewApp
{
    /// <summary>
    /// 可用于自身或导航至 Frame 内部的空白页。
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        private async void OnClick(object sender, RoutedEventArgs e)
        {
            HyperlinkButton ele = sender as HyperlinkButton;

            // 取得URI
            string uristr = ele.Tag as string;
            Uri uri = new Uri(uristr);

            // 获取内容
            string content = ele.Content as string;

            // 创建新的视图
            CoreApplicationView newView = null;
            if (CoreApplication.Views.Count > 1)
            {
                newView = CoreApplication.Views[1];
            }
            // 如果没有这个视图，就创一个
            if (newView == null)
            {
                newView = CoreApplication.CreateNewView();
            }

            int newViewID = default(int);

            // 初始化视图
            // 注意，必须在对应的线程上执行
            await newView.Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal,
                () =>
                {
                    // 获取视图ID，有两种方法
                    // 方法一：GetApplicationViewIdForWindow法，注意线程要对应
                    // Window必须是与当前视图关联的窗口
                    // int viewID = ApplicationView.GetApplicationViewIdForWindow(newView.CoreWindow);
                    // 方法二：最简单
                    // 因为当前执行的代码就在新视图的UI线程上的
                    // 所以GetForCurrentView所返回的就是刚创建的新视图
                    ApplicationView theView = ApplicationView.GetForCurrentView();
                    // 设置一下新窗口的标题（可选）
                    theView.Title = content;
                    // 必须记下视图ID
                    newViewID = theView.Id;
                    // 初始化视图的UI
                    ucDisplayPage uc = Window.Current.Content as ucDisplayPage;
                    if (uc == null)
                    {
                        uc = new ucDisplayPage();
                        uc.HorizontalAlignment = HorizontalAlignment.Stretch;
                        uc.VerticalAlignment = VerticalAlignment.Stretch;
                        uc.MinWidth = 450d;
                        uc.MinHeight = 300d;
                        Window.Current.Content = uc;
                    }
                    uc.TargetWebpageUri = uri;
                    Window.Current.Activate();
                    // 必须调用Activate方法，否则视图不能显示
                    /*
                    注意：
                    在App类中，Window.Current获取的是主视图（程序刚启动时，至少要有一个视图，不然用户连毛都看不见了）所在的窗口。
                    而因为此处的代码是在新创建的视图的UI线程上执行的，故Window.Current自然获取的是新视图所在的窗口。
                    */
                });
            // 开始显示新视图
            bool b = await ApplicationViewSwitcher.TryShowAsStandaloneAsync(newViewID);

            if (b)
            {
                // 成功显示新视图
            }
            else
            {
                // 视图显示失败
            }
        }
    }
}
